@@ -1,12 +1,11 @@
-
 import os
 import compress_pickle
 from unitgrade_private.hidden_gather_upload import load_token, save_token
 from unitgrade_private.plagiarism.mossit import unpack_sources_from_token
 
-# __version__ = "0.0.1"
 
 def cache_write(object, file_name, verbose=True):
+    assert False
     dn = os.path.dirname(file_name)
     if not os.path.exists(dn):
         os.mkdir(dn)
@@ -17,16 +16,15 @@ def cache_write(object, file_name, verbose=True):
 
 
 def cache_exists(file_name):
-    # file_name = cn_(file_name) if cache_prefix else file_name
+    assert False
     return os.path.exists(file_name)
 
 
 def cache_read(file_name):
-    # file_name = cn_(file_name) if cache_prefix else file_name
+    assert False
     if os.path.exists(file_name):
         with open(file_name, 'rb') as f:
             return compress_pickle.load(f, compression="lzma")
-            # return pickle.load(f)
     else:
         return None
 
